summary refs log tree commit diff
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2016-07-20 17:00:50 +0200
committerLudovic Courtès <ludo@gnu.org>2016-07-20 17:02:35 +0200
commitab84b927efa44cd3e81568db4c775f6ab7e3c344 (patch)
tree53734b1b2269d86a0ba3d5d4656251c46359e4a5
parentff6638d112d794c9c433731643711932452fd2ff (diff)
downloadguix-ab84b927efa44cd3e81568db4c775f6ab7e3c344.tar.gz
download: Prepare to support the 'guix publish' /file URLs.
* guix/download.scm (%content-addressed-mirrors): Add 'file' parameter
to the lambda.
* guix/build/download.scm (url-fetch)[content-addressed-uris]: Adjust
accordingly.
-rw-r--r--guix/build/download.scm2
-rw-r--r--guix/download.scm6
2 files changed, 4 insertions, 4 deletions
diff --git a/guix/build/download.scm b/guix/build/download.scm
index 103e784bb1..307258be92 100644
--- a/guix/build/download.scm
+++ b/guix/build/download.scm
@@ -737,7 +737,7 @@ or #f."
     (append-map (lambda (make-url)
                   (filter-map (match-lambda
                                 ((hash-algo . hash)
-                                 (string->uri (make-url hash-algo hash))))
+                                 (string->uri (make-url file hash-algo hash))))
                               hashes))
                 content-addressed-mirrors))
 
diff --git a/guix/download.scm b/guix/download.scm
index bcb043ba80..8f38a4f552 100644
--- a/guix/download.scm
+++ b/guix/download.scm
@@ -232,10 +232,10 @@
 
 (define %content-addressed-mirrors
   ;; List of content-addressed mirrors.  Each mirror is represented as a
   ;; procedure that takes an algorithm (symbol) and a hash (bytevector), and
   ;; returns a URL or #f.
   ;; TODO: Add more.
-  '(list (lambda (algo hash)
+  '(list (lambda (file algo hash)
            ;; 'tarballs.nixos.org' supports several algorithms.
            (string-append "http://tarballs.nixos.org/"
                           (symbol->string algo) "/"
@@ -232,10 +232,10 @@
 (define %content-addressed-mirrors
   ;; List of content-addressed mirrors.  Each mirror is represented as a
-  ;; procedure that takes an algorithm (symbol) and a hash (bytevector), and
-  ;; returns a URL or #f.
+  ;; procedure that takes a file name, an algorithm (symbol) and a hash
+  ;; (bytevector), and returns a URL or #f.
   ;; TODO: Add more.